diff src/conversation.h @ 11454:201617d49573

[gaim-migrate @ 13693] This commit includes a number of changes: 1. Aliases are now used consistently in chats. If the prpl uses unique screen names for chats (e.g. Jabber), then aliases are not used at all. 2. The chat list is now colorized to match the colors used in the chat itself. 3. Buddies are bolded in the chat user list. 4. Buddies are sorted above non-buddies in the chat user list. 5. The chat user list is ellipsized when possible (i.e. on GTK+ 2.6.0 or above). 6. I've accepted patch #1178248, by Matt Amato to add "buddy-added" and "buddy-removed" signals. These were used in my implementation of #3 and #4, to update the GUI when users are added or removed from the buddy list. 7. I've added a "blist-node-aliased" signal that is emitted when a buddy, contact, or chat is aliased. 8. Since it was hard to separate and I need it at some point, I'm letting it slip in... I've changed GaimConversation.log to be a GList named logs. This way, we can have multiple logs for a single conversation. This will be necessary to implement unnamed chat logging in some reasonable fasion (see my notes in the TODO file). committer: Tailor Script <tailor@pidgin.im>
author Richard Laager <rlaager@wiktel.com>
date Tue, 06 Sep 2005 03:04:07 +0000
parents 17142948653e
children 16b0da1f376f
line wrap: on
line diff
--- a/src/conversation.h	Tue Sep 06 02:35:26 2005 +0000
+++ b/src/conversation.h	Tue Sep 06 03:04:07 2005 +0000
@@ -184,12 +184,11 @@
 	void (*write_im)(GaimConversation *conv, const char *who,
 	                 const char *message, GaimMessageFlags flags,
 	                 time_t mtime);
-	void (*write_conv)(GaimConversation *conv, const char *who,
+	void (*write_conv)(GaimConversation *conv, const char *name, const char *alias,
 	                   const char *message, GaimMessageFlags flags,
 	                   time_t mtime);
 
-	void (*chat_add_user)(GaimConversation *conv, const char *user, gboolean new_arrival);
-	void (*chat_add_users)(GaimConversation *conv, GList *users);
+	void (*chat_add_users)(GaimConversation *conv, GList *users, GList *aliases);
 	void (*chat_rename_user)(GaimConversation *conv,
 	                         const char *old_name, const char *new_name);
 	void (*chat_remove_user)(GaimConversation *conv, const char *user);
@@ -206,8 +205,6 @@
 	                            const guchar *data, gsize size);
 	void (*custom_smiley_close)(GaimConversation *conv, const char *smile);
 
-
-
 	/* Events */
 	void (*updated)(GaimConversation *conv, GaimConvUpdateType type);
 
@@ -287,7 +284,7 @@
 
 	gboolean logging;           /**< The status of logging.             */
 
-	GaimLog *log;               /**< This conversation's log            */
+	GList *logs;                /**< This conversation's logs           */
 
 	GList *send_history;        /**< The send history.                  */
 
@@ -1208,14 +1205,22 @@
 /**
  * Adds a list of users to a chat.
  *
  * The data is copied from @a users, so it is up to the developer to
  * free this list after calling this function.
  *
- * @param chat      The chat.
- * @param users     The list of users to add.
- * @param flags     The list of flags for each user.
+ * @param chat         The chat.
+ * @param users        The list of users to add.
+ * @param extra_msgs   An extra message to display with the join message for each
+ *                     user.  This list may be shorter than @a users, in which
+ *                     case, the users after the end of extra_msgs will not have
+ *                     an extra message.  By extension, this means that extra_msgs
+ *                     can simply be @c NULL and none of the users will have an
+ *                     extra message.
+ * @param flags        The list of flags for each user.
+ * @param new_arrivals Decides whether or not to show join notices.
  */
-void gaim_conv_chat_add_users(GaimConvChat *chat, GList *users, GList *flags);
+void gaim_conv_chat_add_users(GaimConvChat *chat, GList *users, GList *extra_msgs,
+							  GList *flags, gboolean new_arrivals);
 
 /**
  * Renames a user in a chat.
@@ -1208,14 +1205,22 @@
  * Adds a list of users to a chat.
  *
- * The data is copied from @a users, so it is up to the developer to
- * free this list after calling this function.
+ * The data is copied from @a users, @a extra_msgs, and @a flags, so it is up to
+ * the caller to free this list after calling this function.
  *